# TC-Analyzer-lib

This repository contains the codes to analyze different platform's data. It includes the scripts to compute heatmaps, memberactivities and graph analytics such as degree centrality, Louvain modularity, local clustering coefficient.

To install the library you could follow the

```bash
pip install tc-analyzer-lib
```
